Precalculated
-------------

.. autosummary::
    :toctree: api/
    :template: ../../../../_templates/class_template.rst

    prismstudio.precalculated.dataitems
    prismstudio.precalculated.alpha_factor_library
